:orphan:

.. _scenario_template:

*************************************
Sample scenario for Ansible platforms
*************************************

*Use this ``rst`` file as a starting point to create a scenario guide for your platform. The sections below are suggestions on what should be in a scenario guide.*

Introductory paragraph.

.. contents::
   :local:

Prerequisites
=============

Describe the requirements and assumptions for this scenario. This should include applicable subsections for hardware, software, and any other caveats to using the scenarios in this guide.

Credentials and authenticating
==============================

Describe credential requirements and how to authenticate to this platform.

Using dynamic inventory
=========================

If applicable, describe how to use a dynamic inventory plugin for this platform.


Example description
===================

Description and code here.  Change the section header to something descriptive about this example, such as "Renaming a virtual machine".  The goal is that this is the text someone would search for to find your example.


Example output
--------------

What the user should expect to see.


Troubleshooting
---------------

What to look for if it breaks.


Conclusion and where to go next
===============================

Recap of important points. For more information please see: links.
